//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Tatsu](index.md)/[withWaiting](with-waiting.md)

# withWaiting

[common]\
abstract fun [withWaiting](with-waiting.md)(tile: [Tile](../-tile/index.md)): [Mentsu](../-mentsu/index.md)

进张后形成的面子
